[![PyPI](https://img.shields.io/pypi/v/slats.svg)](https://pypi.org/project/slats/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/slats.svg)](https://pypi.org/project/slats/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

# slats

### NOTE: this project is an active work in progress

Saves local albums to Spotify.
